"use strict";
this.author    = "Zafrusteria";
this.copyright = "© 2024 Zafrusteria.";
this.license   = "Creative Commons: attribution, non-commercial,  CC BY-NC-SA 4.0 sharealike with clauses - see License.txt";
this.version   = "0.5";

this.name      = "ShrewsRights_yah";
this.description = "ShrewsRights YAH additions";

this.$antiShrew = false;
this.$proShrew  = false;
this.$wanted    = false;

this.$debug = false;

this.startUpComplete = function _ShrewsRights_yah_startUpComplete() {
    if (galaxyNumber != 1) return;

    let SR = worldScripts.ShrewsRights;
    if (this.$debug) log(this.name, "Startup yha SR missionStage: " + SR.$missionStage)

    this._addAntiShrewAds(SR.$missionStage);
    this._addProShrewAds(SR.$missionStage);
    this._addWantedPosters(SR.$missionNewsCount);

    let ws = worldScripts.yah_ad_service;
    if (ws) {
        if (this.$debug) log(this.name, "add yah default ads");
        // just adverts, always available
        for (let i = 0; i < 16; i++) {
            ws._setAd("ShrewsRights_yah_" + (150 + i) + ".png");
        }
    }
}

this.missionScreenOpportunity = function _ShrewsRights_yah_missionScreenOpportunity() {
    if (galaxyNumber != 1 || player.score < 512) return;

    let SR = worldScripts.ShrewsRights;
    if (this.$debug) log(this.name, "missionScreenOpportunity testing yha ads " + SR.$missionStage)

    this._delAntiShrewAds(SR.$missionStage);
    this._addProShrewAds(SR.$missionNewsCount);
    this._addWantedPosters(SR.$missionNewsCount);
}

this._addAntiShrewAds = function _ShrewsRights_yah_addAntiShrewAds(stage) {
    if (! this.$antiShrew && stage > 0 && stage < 14) {
        if (this.$debug) log(this.name, "_addAntiShrewAds yah");

        this.$antiShrew = true;
        let ws = worldScripts.yah_ad_service;
        if (ws) {
            // Ads for eating Shrews, these stop when Shrews are welcomed as citizens
            // the outer loop so they will appear more often.
            for (let j = 0; j < 4; j++) {
                for (let i = 1; i < 6; i++) {
                    ws._setAd("ShrewsRights_yah_" + i + ".png");
                }
            }
            // Take these new ads into use as we added them after setup.
            // ** Probably not the best way to do this. **
            ws._initPool();
        }
    }
}

this._delAntiShrewAds = function _ShrewsRights_yah_delAntiShrewAds(stage) {
    let regexKey = new RegExp("ShrewsRights_yah_[1-4]?[0-9].png");
    function checkAntiShrew(key) { return ! regexKey.test(key);}

    if (this.$antiShrew && stage >= 14) {
        if (this.$debug) log(this.name, "_delAntiShrewAds yah");

        this.$antiShrew = false;
        let ws = worldScripts.yah_ad_service;
        if (ws && ws.$adPool) {
            ws.$adPool = ws.$adPool.filter(checkAntiShrew);
            // remove these ads from the service
            ws._initPool();
        }
    }
}

this._addProShrewAds = function _ShrewsRights_yah_addProShrewAds(news) {
    if (! this.$proShrew && news >= 11) {
        if (this.$debug) log(this.name, "_addProShrewAds yah");
        this.$proShrew = true;
        let ws = worldScripts.yah_ad_service;
        if (ws) {
            for (let i = 0; i < 7; i++) {
                ws._setAd("ShrewsRights_yah_" + (50 + i) + ".png");
            }
            // Take these new ads into use
            ws._initPool();
        }
    }
}

this._addWantedPosters = function _ShrewsRights_yah_addWantedPosters(news) {
    if (! this.$wanted && news >= 16) {
        if (this.$debug) log(this.name, "_addWantedPosters yah");
        this.$wanted = true;
        let ws = worldScripts.yah_ad_service;
        if (ws) {
            for (let i = 0; i < 2; i++) {
                ws._setAd("ShrewsRights_yah_" + (100 + i) + ".png");
            }
            // Take these new ads into use
            ws._initPool();
        }
    }
}